@@ -171,6 +171,14 @@ function get_row_col => sub {
 	$self->get_row($row)->get_col($col);
 };
 
+function set_row => sub {
+	my ($self, $row, $cols) = @_;
+	$row = $self->get_row($row);
+	for (my $i = 0; $i < scalar @{$cols}; $i++) {
+		$row->set_col($i, $cols->[$i] // "");
+	}
+};
+
 function set_row_col => sub {
 	my ($self, $row, $col, $value) = @_;
 	$self->get_row($row)->set_col($col, $value);
@@ -186,4 +194,21 @@ function delete_row_col => sub {
 	$self->get_row($row)->delete_col($col);
 };
 
+function headers_as_array => sub {
+	my ($self) = @_;
+	my @array = map {
+		$_->{label} || $_->{name}
+	} @{$self->headers};
+	return \@array;
+}; 
+
+function headers_stringify => sub {
+	my ($self) = @_;
+	my @array = map {
+		$_->{label} ? sprintf("%s (%s) (%s)", $_->{label}, $_->{name}, $_->{index}) : sptrintf("%s (%s)", $_->{name}, $_->{index})
+	} @{$self->headers};
+	return \@array;
+}; 
+
+
 1;
